@@ -14,7 +14,7 @@ def get_change_logger(LOGFILE):
     formatter = logging.Formatter('%(name)-12s: %(levelname)-8s %(message)s')
     console.setFormatter(formatter)
     logging.getLogger('').addHandler(console)
-    logger = logging.getLogger('change.app')
+    logger = logging.getLogger('quickest.app')
     return logger
 
 def print_progress_bar(current_step, total_steps, width=100):
